/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, NgZone, Renderer2, SimpleChanges } from "@angular/core";
import { PopupService } from "@progress/kendo-angular-popup";
import { PopoverDirectivesBase } from "./directives-base";
import { PopoverService } from "./popover.service";
import * as i0 from "@angular/core";
/**
 * Represents the [`kendoPopoverAnchor`](slug:configuration_popover#toc-popover-anchor) directive.
 * It is used to target an element, which should display a popover on interaction.
 *
 * @example
 * ```ts-no-run
 * <button kendoPopoverAnchor [popover]="myPopover">Show Popover</button>
 * ```
 */
export declare class PopoverAnchorDirective extends PopoverDirectivesBase {
    protected hostEl: ElementRef;
    protected ngZone: NgZone;
    protected popupService: PopupService;
    protected renderer: Renderer2;
    protected popoverService: PopoverService;
    constructor(hostEl: ElementRef, ngZone: NgZone, popupService: PopupService, renderer: Renderer2, popoverService: PopoverService);
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Shows the Popover. [See example]({% slug programmaticcontrol_popover %})
     */
    show(): void;
    /**
     * Toggles the visibility of the Popover. [See example]({% slug programmaticcontrol_popover %})
     */
    toggle(): void;
    protected subscribeToShowEvents(arr: any[]): void;
    protected subscribeClick(): void;
    protected mouseenterHandler: () => void;
    protected mouseleaveHandler: () => void;
    protected focusHandler: () => void;
    protected blurHandler: (args: any) => void;
    /**
     * @hidden
     */
    private onClick;
    private controlVisibility;
    static ɵfac: i0.ɵɵFactoryDeclaration<PopoverAnchorDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<PopoverAnchorDirective, "[kendoPopoverAnchor]", ["kendoPopoverAnchor"], {}, {}, never, never, true, never>;
}
