/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { InjectionToken } from '@angular/core';
import { Position } from '../models/position.type';
import { ShowOption } from '../models/show.option.type';
import * as i0 from "@angular/core";
/**
 * Obsolete. Provide the TooltipSettings class instead.
 *
 * @hidden
 */
export declare const TOOLTIP_SETTINGS: InjectionToken<string>;
/**
 * Provides a global configuration for the Kendo UI Tooltip. Once injected through
 * the `AppComponent` constructor, the configuration properties can be overridden.
 *
 * @example
 * ```ts-no-run
 * import { TooltipSettings } from '@progress/kendo-angular-tooltip';
 *
 * _@Component({
 *    selector: 'my-app',
 *    template: `
 *      <div kendoTooltip>
 *          <button title="Saves the current document">Save</button>
 *      </div>`,
 *    providers: [{
 *        provide: TooltipSettings,
 *        useFactory: (): TooltipSettings => ({
 *          // Override default values of tooltips if wanted
 *          position: 'right'
 *        })
 *    }]
 * })
 * export class AppComponent { }
 * ```
 */
export declare class TooltipSettings {
    /**
     * Specifies if the Тooltip will display a callout arrow.
     *
     * The possible values are:
     * * `true` (default)
     * * `false`
     */
    callout?: boolean;
    /**
     * Specifies the title of the close button.
     */
    closeTitle: string;
    /**
     * Specifies the position of the Tooltip that is
     * relative to the anchor element.
     *
     * The possible values are:
     * * `top` (default)
     * * `bottom`
     * * `left`
     * * `right`
     */
    position?: Position;
    /**
     * Specifies when the Тooltip will be rendered.
     *
     * The possible values are:
     * * `hover` (default)
     * * `click`
     * * `none`
     */
    showOn?: ShowOption;
    /**
     * Specifies the delay in milliseconds before the Tooltip is shown.
     * * `100` (default) milliseconds.
     */
    showAfter?: number;
    /**
     * @hidden
     */
    constructor();
    static ɵfac: i0.ɵɵFactoryDeclaration<TooltipSettings, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TooltipSettings>;
}
